==> Spire.Pdf-9.12.0-py3-none-win_amd64.whl: spire/pdf/PdfFreeTextAnnotationWidget.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfFreeTextAnnotationWidget(PdfMarkUpAnnotationWidget):
    """
    Represents the free text annotation widget.
    """

    @property
    def ModifiedDate(self) -> 'DateTime':
        """
        Gets or sets the date and time when the annotation was most recently modified.
        """
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_ModifiedDate.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_ModifiedDate.restype = c_void_p
        intPtr = GetDllLibPdf().PdfFreeTextAnnotationWidget_get_ModifiedDate(self.Ptr)
        ret = None if intPtr == None else DateTime(intPtr)
        return ret

    @ModifiedDate.setter
    def ModifiedDate(self, value: 'DateTime'):
        """
        Sets the date and time when the annotation was most recently modified.
        """
        GetDllLibPdf().PdfFreeTextAnnotationWidget_set_ModifiedDate.argtypes = [c_void_p, c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotationWidget_set_ModifiedDate(self.Ptr, value.Ptr)

    @property
    def RectangularDifferenceArray(self) -> List[float]:
        """
        Gets or sets the rectangular differences array.
        """
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_RectangularDifferenceArray.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_RectangularDifferenceArray.restype = IntPtrArray
        intPtrArray = GetDllLibPdf().PdfFreeTextAnnotationWidget_get_RectangularDifferenceArray(self.Ptr)
        ret = GetVectorFromArray(intPtrArray, c_float)
        return ret

    @RectangularDifferenceArray.setter
    def RectangularDifferenceArray(self, value: List[float]):
        """
        Sets the rectangular differences array.
        """
        vCount = len(value)
        ArrayType = c_float * vCount
        vArray = ArrayType()
        for i in range(0, vCount):
            vArray[i] = value[i]
        GetDllLibPdf().PdfFreeTextAnnotationWidget_set_RectangularDifferenceArray.argtypes = [c_void_p, ArrayType, c_int]
        GetDllLibPdf().PdfFreeTextAnnotationWidget_set_RectangularDifferenceArray(self.Ptr, vArray, vCount)

    @property
    def Intent(self) -> 'PdfAnnotationIntent':
        """
        Gets a name describing the intent of the free text annotation.
        """
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_Intent.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_Intent.restype = c_int
        ret = GetDllLibPdf().PdfFreeTextAnnotationWidget_get_Intent(self.Ptr)
        objwrapped = PdfAnnotationIntent(ret)
        return objwrapped

    @property
    def LineEndingStyle(self) -> 'PdfLineEndingStyle':
        """
        Gets the line ending style.
        """
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_LineEndingStyle.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_LineEndingStyle.restype = c_int
        ret = GetDllLibPdf().PdfFreeTextAnnotationWidget_get_LineEndingStyle(self.Ptr)
        objwrapped = PdfLineEndingStyle(ret)
        return objwrapped

    @property
    def CalloutLines(self) -> List['PointF']:
        """
        Gets the callout line.
        """
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_CalloutLines.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_CalloutLines.restype = IntPtrArray
        intPtrArray = GetDllLibPdf().PdfFreeTextAnnotationWidget_get_CalloutLines(self.Ptr)
        ret = GetObjVectorFromArray(intPtrArray, PointF)
        return ret

    @property
    def BorderWidth(self) -> float:
        """
        Gets the border width.
        """
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_BorderWidth.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_BorderWidth.restype = c_float
        ret = GetDllLibPdf().PdfFreeTextAnnotationWidget_get_BorderWidth(self.Ptr)
        return ret

    @property
    def BorderColor(self) -> 'PdfRGBColor':
        """
        Gets the border color.
        """
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_BorderColor.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_BorderColor.restype = c_void_p
        intPtr = GetDllLibPdf().PdfFreeTextAnnotationWidget_get_BorderColor(self.Ptr)
        ret = None if intPtr == None else PdfRGBColor(intPtr)
        return ret

    @property
    def BorderStyle(self) -> 'PdfBorderStyle':
        """
        Gets the border style.
        """
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_BorderStyle.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_BorderStyle.restype = c_int
        ret = GetDllLibPdf().PdfFreeTextAnnotationWidget_get_BorderStyle(self.Ptr)
        objwrapped = PdfBorderStyle(ret)
        return objwrapped

    def ObjectID(self) -> int:
        """
        Represents the Form field identifier.
        """
        GetDllLibPdf().PdfFreeTextAnnotationWidget_ObjectID.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotationWidget_ObjectID.restype = c_int
        ret = GetDllLibPdf().PdfFreeTextAnnotationWidget_ObjectID(self.Ptr)
        return ret

==> Spire.Pdf-10.12.1-py3-none-win_amd64.whl: spire/pdf/PdfFreeTextAnnotationWidget.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar, Union, Generic, List, Tuple
from spire.pdf.common import *
from spire.pdf import *
from ctypes import *
import abc

class PdfFreeTextAnnotationWidget(PdfMarkUpAnnotationWidget):
    """
    Represents the free text annotation widget.
    """

    @property
    def ModifiedDate(self) -> 'DateTime':
        """
        Gets or sets the date and time when the annotation was most recently modified.
        """
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_ModifiedDate.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_ModifiedDate.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfFreeTextAnnotationWidget_get_ModifiedDate,self.Ptr)
        ret = None if intPtr == None else DateTime(intPtr)
        return ret

    @ModifiedDate.setter
    def ModifiedDate(self, value: 'DateTime'):
        """
        Sets the date and time when the annotation was most recently modified.
        """
        GetDllLibPdf().PdfFreeTextAnnotationWidget_set_ModifiedDate.argtypes = [c_void_p, c_void_p]
        CallCFunction(GetDllLibPdf().PdfFreeTextAnnotationWidget_set_ModifiedDate,self.Ptr, value.Ptr)

    @property
    def RectangularDifferenceArray(self) -> List[float]:
        """
        Gets or sets the rectangular differences array.
        """
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_RectangularDifferenceArray.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_RectangularDifferenceArray.restype = IntPtrArray
        intPtrArray = CallCFunction(GetDllLibPdf().PdfFreeTextAnnotationWidget_get_RectangularDifferenceArray,self.Ptr)
        ret = GetVectorFromArray(intPtrArray, c_float)
        return ret

    @RectangularDifferenceArray.setter
    def RectangularDifferenceArray(self, value: List[float]):
        """
        Sets the rectangular differences array.
        """
        vCount = len(value)
        ArrayType = c_float * vCount
        vArray = ArrayType()
        for i in range(0, vCount):
            vArray[i] = value[i]
        GetDllLibPdf().PdfFreeTextAnnotationWidget_set_RectangularDifferenceArray.argtypes = [c_void_p, ArrayType, c_int]
        CallCFunction(GetDllLibPdf().PdfFreeTextAnnotationWidget_set_RectangularDifferenceArray,self.Ptr, vArray, vCount)

    @property
    def Intent(self) -> 'PdfAnnotationIntent':
        """
        Gets a name describing the intent of the free text annotation.
        """
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_Intent.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_Intent.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfFreeTextAnnotationWidget_get_Intent,self.Ptr)
        objwrapped = PdfAnnotationIntent(ret)
        return objwrapped

    @property
    def LineEndingStyle(self) -> 'PdfLineEndingStyle':
        """
        Gets the line ending style.
        """
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_LineEndingStyle.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_LineEndingStyle.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfFreeTextAnnotationWidget_get_LineEndingStyle,self.Ptr)
        objwrapped = PdfLineEndingStyle(ret)
        return objwrapped

    @property
    def CalloutLines(self) -> List['PointF']:
        """
        Gets the callout line.
        """
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_CalloutLines.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_CalloutLines.restype = IntPtrArray
        intPtrArray = CallCFunction(GetDllLibPdf().PdfFreeTextAnnotationWidget_get_CalloutLines,self.Ptr)
        ret = GetObjVectorFromArray(intPtrArray, PointF)
        return ret

    @property
    def BorderWidth(self) -> float:
        """
        Gets the border width.
        """
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_BorderWidth.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_BorderWidth.restype = c_float
        ret = CallCFunction(GetDllLibPdf().PdfFreeTextAnnotationWidget_get_BorderWidth,self.Ptr)
        return ret

    @property
    def BorderColor(self) -> 'PdfRGBColor':
        """
        Gets the border color.
        """
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_BorderColor.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_BorderColor.restype = c_void_p
        intPtr = CallCFunction(GetDllLibPdf().PdfFreeTextAnnotationWidget_get_BorderColor,self.Ptr)
        ret = None if intPtr == None else PdfRGBColor(intPtr)
        return ret

    @property
    def BorderStyle(self) -> 'PdfBorderStyle':
        """
        Gets the border style.
        """
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_BorderStyle.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotationWidget_get_BorderStyle.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfFreeTextAnnotationWidget_get_BorderStyle,self.Ptr)
        objwrapped = PdfBorderStyle(ret)
        return objwrapped

    def ObjectID(self) -> int:
        """
        Represents the Form field identifier.
        """
        GetDllLibPdf().PdfFreeTextAnnotationWidget_ObjectID.argtypes = [c_void_p]
        GetDllLibPdf().PdfFreeTextAnnotationWidget_ObjectID.restype = c_int
        ret = CallCFunction(GetDllLibPdf().PdfFreeTextAnnotationWidget_ObjectID,self.Ptr)
        return ret
